@@ -1,51 +1,54 @@
+from __future__ import annotations
+
+from collections.abc import AsyncGenerator
 import datetime
+import json
 import logging
-from urllib.parse import urlencode, urlparse, parse_qs
-from typing import AsyncGenerator
+from urllib.parse import parse_qs, urlencode, urlparse
 
 import aiohttp
 
 from myPyllant.models import (
     Device,
     DeviceData,
+    DeviceDataBucketResolution,
+    DHWOperationMode,
     DomesticHotWater,
     System,
     Zone,
-    DeviceDataBucketResolution,
     ZoneHeatingOperatingMode,
-    DHWOperationMode,
 )
 from myPyllant.utils import (
+    datetime_format,
     dict_to_snake_case,
     generate_code,
     random_string,
-    datetime_format,
 )
 
-_LOGGER = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
-login_url = "https://vaillant-prod.okta.com/api/v1/authn"
-oauth_client_id = "0oarllti4egHi7Nwx4x6"
-base_api_url = (
-    "https://api.vaillant-group.com/service-connected-control/end-user-app-api/v1"
-)
-
-login_headers = {
+LOGIN_URL = "https://vaillant-prod.okta.com/api/v1/authn"
+LOGIN_HEADERS = {
     "accept": "application/json",
     "content-type": "application/json",
     "user-agent": "myVAILLANT/11835 CFNetwork/1240.0.4 Darwin/20.6.0",
     "x-okta-user-agent-extended": "okta-auth-js/5.4.1 okta-react-native/2.7.0 "
-                                  "react-native/>=0.70.1 ios/14.8 nodejs/undefined",
+    "react-native/>=0.70.1 ios/14.8 nodejs/undefined",
     "accept-language": "de-de",
 }
 
+OAUTH_CLIENT_ID = "0oarllti4egHi7Nwx4x6"
+API_URL_BASE = (
+    "https://api.vaillant-group.com/service-connected-control/end-user-app-api/v1"
+)
 
-class MyPyllantAPI(object):
+
+class MyPyllantAPI:
     username: str = None
     password: str = None
-    aiohttp_session = None
-    oauth_session = {}
+    aiohttp_session: aiohttp.ClientSession = None
+    oauth_session: dict = {}
     oauth_session_expires: datetime.datetime = None
 
     def __init__(self, username: str, password: str) -> None:
@@ -56,11 +59,11 @@ class MyPyllantAPI(object):
             raise_for_status=True,
         )
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> MyPyllantAPI:
         await self.login()
         return self
 
-    async def __aexit__(self, exc_type, exc, tb):
+    async def __aexit__(self, exc_type, exc, tb) -> None:
         await self.aiohttp_session.close()
 
     async def login(self):
@@ -71,11 +74,13 @@ class MyPyllantAPI(object):
             "password": self.password,
         }
         async with self.aiohttp_session.post(
-            login_url, json=login_payload, headers=login_headers, raise_for_status=False
+            LOGIN_URL, json=login_payload, headers=LOGIN_HEADERS, raise_for_status=False
         ) as resp:
             login_json = await resp.json()
             if resp.status >= 400:
-                _LOGGER.error(f'Could not log in, got status {resp.status} this response: {login_json}')
+                logger.error(
+                    f"Could not log in, got status {resp.status} this response: {login_json}"
+                )
                 raise Exception(login_json["errorSummary"])
             session_token = login_json["sessionToken"]
 
@@ -89,7 +94,7 @@ class MyPyllantAPI(object):
             "scope": "openid profile offline_access",
             "code_challenge": code_challenge,
             "redirect_uri": "com.okta.vaillant-prod:/callback",
-            "client_id": oauth_client_id,
+            "client_id": OAUTH_CLIENT_ID,
             "state": state,
         }
         authorize_headers = {
@@ -106,7 +111,9 @@ class MyPyllantAPI(object):
             authorize_url, headers=authorize_headers, allow_redirects=False
         ) as resp:
             await resp.text()
-            _LOGGER.debug(f'Got location from authorize endpoint: {resp.headers["Location"]}')
+            logger.debug(
+                f'Got location from authorize endpoint: {resp.headers["Location"]}'
+            )
             parsed_url = urlparse(resp.headers["Location"])
             code = parse_qs(parsed_url.query)["code"]
 
@@ -114,7 +121,7 @@ class MyPyllantAPI(object):
             "code": code,
             "code_verifier": code_verifier,
             "redirect_uri": "com.okta.vaillant-prod:/callback",
-            "client_id": oauth_client_id,
+            "client_id": OAUTH_CLIENT_ID,
             "grant_type": "authorization_code",
         }
         token_headers = {
@@ -128,20 +135,20 @@ class MyPyllantAPI(object):
             token_url, data=token_payload, headers=token_headers
         ) as resp:
             self.oauth_session = await resp.json()
-            _LOGGER.debug(f'Got session {self.oauth_session}')
+            logger.debug(f"Got session {self.oauth_session}")
             self.set_session_expires()
 
     def set_session_expires(self):
         self.oauth_session_expires = datetime.datetime.now() + datetime.timedelta(
             seconds=self.oauth_session["expires_in"]
         )
-        _LOGGER.debug(f'Session expires in {self.oauth_session_expires}')
+        logger.debug(f"Session expires in {self.oauth_session_expires}")
 
     async def refresh_token(self):
         refresh_url = "https://vaillant-prod.okta.com/oauth2/default/v1/token"
         refresh_payload = {
             "refresh_token": self.oauth_session["refresh_token"],
-            "client_id": oauth_client_id,
+            "client_id": OAUTH_CLIENT_ID,
             "grant_type": "refresh_token",
         }
         refresh_headers = {
@@ -175,20 +182,20 @@ class MyPyllantAPI(object):
         }
 
     async def get_systems(self) -> AsyncGenerator[System, int]:
-        systems_url = f"{base_api_url}/systems"
+        systems_url = f"{API_URL_BASE}/systems"
         async with self.aiohttp_session.get(
             systems_url, headers=self.get_authorized_headers()
         ) as systems_resp:
             for system_json in await systems_resp.json():
-                _LOGGER.debug(f'Got systems response {system_json}')
+                logger.debug(f"Got systems response {system_json}")
                 system_id = system_json["systemId"]
-                system_url = f"{base_api_url}/emf/v2/{system_id}/currentSystem"
+                system_url = f"{API_URL_BASE}/emf/v2/{system_id}/currentSystem"
 
                 async with self.aiohttp_session.get(
                     system_url, headers=self.get_authorized_headers()
                 ) as current_system_resp:
                     current_system_json = await current_system_resp.json()
-                    _LOGGER.debug(f'Got current system response {current_system_json}')
+                    logger.debug(f"Got current system response {current_system_json}")
                 system = System(
                     id=system_id,
                     current_system=current_system_json,
@@ -235,13 +242,15 @@ class MyPyllantAPI(object):
                 "startDate": start_date,
                 "endDate": end_date,
             }
-            device_buckets_url = f"{base_api_url}/emf/v2/{device.system.id}/" \
-                                 f"devices/{device.device_uuid}/buckets?{urlencode(querystring)}"
+            device_buckets_url = (
+                f"{API_URL_BASE}/emf/v2/{device.system.id}/"
+                f"devices/{device.device_uuid}/buckets?{urlencode(querystring)}"
+            )
             async with self.aiohttp_session.get(
                 device_buckets_url, headers=self.get_authorized_headers()
             ) as device_buckets_resp:
                 device_buckets_json = await device_buckets_resp.json()
-                _LOGGER.debug(f'Got data buckets response {device_buckets_json}')
+                logger.debug(f"Got data buckets response {device_buckets_json}")
                 yield DeviceData(
                     device=device,
                     **dict_to_snake_case(device_buckets_json),
@@ -250,11 +259,11 @@ class MyPyllantAPI(object):
     async def set_zone_heating_operating_mode(
         self, zone: Zone, mode: ZoneHeatingOperatingMode
     ):
-        url = f"{base_api_url}/systems/{zone.system_id}/zones/{zone.index}/heatingOperationMode"
+        url = f"{API_URL_BASE}/systems/{zone.system_id}/zones/{zone.index}/heatingOperationMode"
         return await self.aiohttp_session.post(
             url,
             json={
-                "heatingOperationMode": str(ZoneHeatingOperatingMode(mode)),
+                "heatingOperationMode": str(mode),
             },
             headers=self.get_authorized_headers(),
         )
@@ -262,7 +271,7 @@ class MyPyllantAPI(object):
     async def quick_veto_zone_temperature(
         self, zone: Zone, temperature: float, duration_hours: int
     ):
-        url = f"{base_api_url}/systems/{zone.system_id}/zones/{zone.index}/quickVeto"
+        url = f"{API_URL_BASE}/systems/{zone.system_id}/zones/{zone.index}/quickVeto"
         return await self.aiohttp_session.post(
             url,
             json={
@@ -273,13 +282,13 @@ class MyPyllantAPI(object):
         )
 
     async def cancel_quick_veto_zone_temperature(self, zone: Zone):
-        url = f"{base_api_url}/systems/{zone.system_id}/zones/{zone.index}/quickVeto"
+        url = f"{API_URL_BASE}/systems/{zone.system_id}/zones/{zone.index}/quickVeto"
         return await self.aiohttp_session.delete(
             url, headers=self.get_authorized_headers()
         )
 
     async def set_set_back_temperature(self, zone: Zone, temperature: float):
-        url = f"{base_api_url}/systems/{zone.system_id}/zones/{zone.index}/setBackTemperature"
+        url = f"{API_URL_BASE}/systems/{zone.system_id}/zones/{zone.index}/setBackTemperature"
         return await self.aiohttp_session.patch(
             url,
             json={"setBackTemperature": temperature},
@@ -287,14 +296,19 @@ class MyPyllantAPI(object):
         )
 
     async def set_holiday(
-        self, system: System, start: datetime.datetime, end: datetime.datetime = None
+        self,
+        system: System,
+        start: datetime.datetime = None,
+        end: datetime.datetime = None,
     ):
+        if not start:
+            start = datetime.datetime.now()
         if not end:
             # Set away for a long time if no end date is set
             end = start + datetime.timedelta(days=365)
         if not start < end:
-            raise Exception('Start of holiday mode must be before end')
-        url = f"{base_api_url}/systems/{system.id}/holiday"
+            raise Exception("Start of holiday mode must be before end")
+        url = f"{API_URL_BASE}/systems/{system.id}/holiday"
         data = {
             "holidayStartDateTime": datetime_format(start, with_microseconds=True),
             "holidayEndDateTime": datetime_format(end, with_microseconds=True),
@@ -304,7 +318,7 @@ class MyPyllantAPI(object):
         )
 
     async def cancel_holiday(self, system: System):
-        url = f"{base_api_url}/systems/{system.id}/holiday"
+        url = f"{API_URL_BASE}/systems/{system.id}/holiday"
         return await self.aiohttp_session.delete(
             url, headers=self.get_authorized_headers()
         )
@@ -313,22 +327,24 @@ class MyPyllantAPI(object):
         self, domestic_hot_water: DomesticHotWater, temperature: int | float
     ):
         if isinstance(temperature, float):
-            _LOGGER.warning(f'Domestic hot water can only be set to whole numbers')
+            logger.warning(f"Domestic hot water can only be set to whole numbers")
             temperature = int(round(temperature, 0))
-        url = f"{base_api_url}/systems/{domestic_hot_water.system_id}/" \
-              f"domesticHotWater/{domestic_hot_water.index}/temperature"
+        url = (
+            f"{API_URL_BASE}/systems/{domestic_hot_water.system_id}/"
+            f"domesticHotWater/{domestic_hot_water.index}/temperature"
+        )
         return await self.aiohttp_session.post(
             url, json={"setPoint": temperature}, headers=self.get_authorized_headers()
         )
 
     async def boost_domestic_hot_water(self, domestic_hot_water: DomesticHotWater):
-        url = f"{base_api_url}/systems/{domestic_hot_water.system_id}/domesticHotWater/{domestic_hot_water.index}/boost"
+        url = f"{API_URL_BASE}/systems/{domestic_hot_water.system_id}/domesticHotWater/{domestic_hot_water.index}/boost"
         return await self.aiohttp_session.post(
             url, json={}, headers=self.get_authorized_headers()
         )
 
     async def cancel_hot_water_boost(self, domestic_hot_water: DomesticHotWater):
-        url = f"{base_api_url}/systems/{domestic_hot_water.system_id}/domesticHotWater/{domestic_hot_water.index}/boost"
+        url = f"{API_URL_BASE}/systems/{domestic_hot_water.system_id}/domesticHotWater/{domestic_hot_water.index}/boost"
         return await self.aiohttp_session.delete(
             url, headers=self.get_authorized_headers()
         )
@@ -336,12 +352,14 @@ class MyPyllantAPI(object):
     async def set_domestic_hot_water_operation_mode(
         self, domestic_hot_water: DomesticHotWater, mode: DHWOperationMode
     ):
-        url = f"{base_api_url}/systems/{domestic_hot_water.system_id}/" \
-              f"domesticHotWater/{domestic_hot_water.index}/operationMode"
+        url = (
+            f"{API_URL_BASE}/systems/{domestic_hot_water.system_id}/"
+            f"domesticHotWater/{domestic_hot_water.index}/operationMode"
+        )
         return await self.aiohttp_session.post(
             url,
             json={
-                "operationMode": str(DHWOperationMode(mode)),
+                "operationMode": str(mode),
             },
             headers=self.get_authorized_headers(),
         )
