@@ -1,11 +1,11 @@
-import logging
-from typing import Any, Dict, List, Mapping
+from collections.abc import Mapping
 import datetime
 from enum import Enum
+import logging
+from typing import Any, Dict, List
 
 from pydantic import BaseModel
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -81,7 +81,7 @@ class Circuit(BaseModel):
     min_flow_temperature_setpoint: float
     mixer_circuit_type_external: str
     set_back_mode_enabled: bool
-    zones: List = []
+    zones: list = []
 
 
 class DomesticHotWater(BaseModel):
@@ -98,23 +98,24 @@ class DomesticHotWater(BaseModel):
 
 class System(BaseModel):
     id: str
-    status: Dict[str, bool]
-    devices: List[Dict]
-    current_system: Dict = {}
-    system_configuration: Dict = {}
-    system_control_state: Dict = {}
-    gateway: Dict = {}
+    status: dict[str, bool]
+    devices: list[dict]
+    current_system: dict = {}
+    system_configuration: dict = {}
+    system_control_state: dict = {}
+    gateway: dict = {}
     has_ownership: bool
-    zones: List[Zone] = []
-    circuits: List[Circuit] = []
-    domestic_hot_water: List[DomesticHotWater] = []
+    zones: list[Zone] = []
+    circuits: list[Circuit] = []
+    domestic_hot_water: list[DomesticHotWater] = []
 
     def __init__(self, **data: Any) -> None:
         super().__init__(**data)
         self.zones = [Zone(system_id=self.id, **z) for z in self._raw_zones]
         self.circuits = [Circuit(system_id=self.id, **c) for c in self._raw_circuits]
         self.domestic_hot_water = [
-            DomesticHotWater(system_id=self.id, **d) for d in self._raw_domestic_hot_water
+            DomesticHotWater(system_id=self.id, **d)
+            for d in self._raw_domestic_hot_water
         ]
 
     @property
@@ -122,7 +123,7 @@ class System(BaseModel):
         try:
             return self.system_control_state["control_state"].get("zones", [])
         except KeyError as e:
-            logger.error('Could not get zones from system control state', exc_info=e)
+            logger.error("Could not get zones from system control state", exc_info=e)
             return []
 
     @property
@@ -130,15 +131,19 @@ class System(BaseModel):
         try:
             return self.system_control_state["control_state"].get("circuits", [])
         except KeyError as e:
-            logger.error('Could not get circuits from system control state', exc_info=e)
+            logger.error("Could not get circuits from system control state", exc_info=e)
             return []
 
     @property
     def _raw_domestic_hot_water(self):
         try:
-            return self.system_control_state["control_state"].get("domestic_hot_water", [])
+            return self.system_control_state["control_state"].get(
+                "domestic_hot_water", []
+            )
         except KeyError as e:
-            logger.error('Could not get domestic hot water from system control state', exc_info=e)
+            logger.error(
+                "Could not get domestic hot water from system control state", exc_info=e
+            )
             return []
 
     @property
@@ -149,11 +154,11 @@ class System(BaseModel):
 
     @property
     def status_online(self) -> bool | None:
-        return self.status['online'] if 'online' in self.status else None
+        return self.status["online"] if "online" in self.status else None
 
     @property
     def status_error(self) -> bool | None:
-        return self.status['error'] if 'error' in self.status else None
+        return self.status["error"] if "error" in self.status else None
 
     @property
     def water_pressure(self):
@@ -166,7 +171,7 @@ class System(BaseModel):
         try:
             return self.system_control_state["control_state"]["general"]["system_mode"]
         except KeyError as e:
-            logger.error('Could not get mode from system control state', exc_info=e)
+            logger.error("Could not get mode from system control state", exc_info=e)
             return None
 
 
@@ -175,8 +180,8 @@ class Device(BaseModel):
     device_uuid: str
     name: str = ""
     product_name: str
-    diagnostic_trouble_codes: List = []
-    properties: List = []
+    diagnostic_trouble_codes: list = []
+    properties: list = []
     ebus_id: str
     article_number: str
     device_serial_number: str
@@ -184,7 +189,7 @@ class Device(BaseModel):
     first_data: datetime.datetime
     last_data: datetime.datetime
     operational_data: dict = {}
-    data: List["DeviceData"] = []
+    data: list["DeviceData"] = []
 
     @property
     def name_display(self):
@@ -199,8 +204,8 @@ class DeviceDataBucket(BaseModel):
 
 class DeviceData(BaseModel):
     def __init__(self, device: Device = None, **data: Mapping) -> None:
-        data['data_from'] = data.pop('from') if 'from' in data else None
-        data['data_to'] = data.pop('to') if 'to' in data else None
+        data["data_from"] = data.pop("from") if "from" in data else None
+        data["data_to"] = data.pop("to") if "to" in data else None
         super().__init__(device=device, **data)
 
     device: Device | None
@@ -212,7 +217,7 @@ class DeviceData(BaseModel):
     operation_mode: str
     energy_type: str | None
     value_type: str | None
-    data: List[DeviceDataBucket] = []
+    data: list[DeviceDataBucket] = []
 
 
 Device.update_forward_refs()
